

## Quick start


```bash
# for server
python server/server.py

# for client
python client/client.py
```

for MacOS

```bash
# for server
python launcher_macos.py

# for client
python client/client.py
```

